@@ -1,14 +1,19 @@
-from Base import *
+from .Base import *
 
 
 class Method(Base):
     IDEAL = 'ideal'
-    PAYSAFECARD = 'paysafecard'
     CREDITCARD = 'creditcard'
     MISTERCASH = 'mistercash'
+    SOFORT = 'sofort'
     BANKTRANSFER = 'banktransfer'
-    PAYPAL = 'paypal'
+    DIRECTDEBIT = 'directdebit'
     BITCOIN = 'bitcoin'
+    PAYPAL = 'paypal'
+    BELFIUS = 'belfius'
+    PAYSAFECARD = 'paysafecard'
+    PODIUMCADEAUKAART = 'podiumcadeaukaart'
+    KBC = 'kbc'
 
     def getMinimumAmount(self):
         if not self['amount'] or 'minimum' not in self['amount']:
