@@ -10,15 +10,17 @@ class Payments(Base):
         return Payment(result)
 
     def get(self, payment_id):
-        if not payment_id or self.RESOURCE_ID_PREFIX not in payment_id:
+        if not payment_id or not payment_id.startswith(self.RESOURCE_ID_PREFIX):
             raise Error(
                 'Invalid payment ID: "%s". A payment ID should start with "%s".' % (payment_id, self.RESOURCE_ID_PREFIX)
             )
         return super(Payments, self).get(payment_id)
 
-    def refund(self, payment):
-        return self.client.payment_refunds.on(payment).create()
+    def refunds(self, payment):
+        return self.client.payment_refunds.on(payment)
 
+    def refund(self, payment, data=None):
+        return self.refunds(payment).create(data)
 
 class Refunds(Base):
     payment_id = None
@@ -27,8 +29,11 @@ class Refunds(Base):
         return Refund(result)
 
     def getResourceName(self):
-        return 'payments/%i/refunds' % self.payment_id
+        return 'payments/%s/refunds' % self.payment_id
+
+    def withParentId(self, payment_id):
+        self.payment_id = payment_id
+        return self
 
     def on(self, payment):
-        self.payment_id = payment['id']
-        return self
\ No newline at end of file
+        return self.withParentId(payment['id'])
